Learn R Programming

covid19us (version 0.1.9)

get_counties_info: Get COVID-related information for certain counties

Description

Currently limited to the worst-affected counties in mostly Washington state, California, and New York.

Usage

get_counties_info()

Arguments

Value

A tibble with one row per county and their COVID website information.

Examples

Run this code
# \donttest{
get_counties_info()
# }

Run the code above in your browser using DataLab