Learn R Programming

covid19us (version 0.1.9)

get_info_covid19us: Get info about this dataset

Description

Get info about this dataset

Usage

get_info_covid19us()

Arguments

Value

A tibble with information about where the data is pulled from, details about the dataset, what the data types are, etc.

Examples

Run this code
# \donttest{
get_info_covid19us()
# }

Run the code above in your browser using DataLab