get_states_daily: Get daily counts for every state
Description
Daily counts are updated every day at 4pm EST. This is the only function that takes arguments.
Usage
get_states_daily(state = "all", date = "all")
Value
A tibble with one row per state for all dates available with columns for individuals' COVID statuses (positive, negative, pending, death) and their total.
Arguments
state
State abbreviation for a specific state or all states with "all".
date
For a specific date, a character or date vector of length 1 coercible to a date with lubridate::as_date().