Learn R Programming

covid19us (version 0.1.9)

get_states_info: Get COVID-related information for each state

Description

Get COVID-related information for each state

Usage

get_states_info()

Arguments

Value

A tibble with one row per state incluing information on the state's data_site where the data was pulled from and the covid_19_site where data is published.

Examples

Run this code
# \donttest{
get_states_info()
# }

Run the code above in your browser using DataLab