Learn R Programming

covid19us (version 0.1.9)

get_tracker_urls: Get URLs and their details for each state

Description

Get URLs and their details for each state

Usage

get_tracker_urls()

Arguments

Value

A tibble with one row for every state, the URL used by scrapers to get data, and a filter column that provices the xpath or CSS selector used by the COVID-19 Tracking Project's scraper to get this data.

Examples

Run this code
# \donttest{
get_tracker_urls()
# }

Run the code above in your browser using DataLab