Learn R Programming

covid19us (version 0.1.9)

get_us_daily: Get daily US counts

Description

Updated every day at 4pm.

Usage

get_us_daily()

Arguments

Value

A tibble with one row per date in which data is available and counts for each of those states.

Examples

Run this code
# \donttest{
get_us_daily()
# }

Run the code above in your browser using DataLab