powered by
Currently limited to the worst-affected counties in mostly Washington state, California, and New York.
get_counties_info()
A tibble with one row per county and their COVID website information.
# \donttest{ get_counties_info() # }
Run the code above in your browser using DataLab