powered by
Get info about this dataset
get_info_covid19us()
A tibble with information about where the data is pulled from, details about the dataset, what the data types are, etc.
# \donttest{ get_info_covid19us() # }
Run the code above in your browser using DataLab