powered by
Updated every day at 4pm.
get_us_daily()
A tibble with one row per date in which data is available and counts for each of those states.
# \donttest{ get_us_daily() # }
Run the code above in your browser using DataLab